@@ -154,6 +154,10 @@ class MQ(object):
             self, queue, data, messageID="*", maxlen=1000, trimImmediately=False
     ):
         if self._p2p:
+            success = data.get('success')
+            if success != 'true':
+                return
+
             for target, data4in in self._sendP2PMessages(data):
                 target_queue = f'{queue}-{target}'
                 logger.debug(f'send p2p message to {target}: {data4in}')
@@ -181,7 +185,10 @@ class MQ(object):
             for tgt in connections:
                 d = data.get(port_id)
                 if d:
-                    data4in = {"id": data['request_id'], tgt.port: d, "extra": data["extra"]}
+                    data4in = {"id": data['request_id'], tgt.port: d}
+                    extra = data.get('extra')
+                    if extra:
+                        data4in["extra"] = extra
                     yield tgt.process, data4in
 
     def recvMessages(
